MacOS Setup — PyMedPhys

Toggle navigation sidebar
Toggle in-page Table of Contents

# MacOS Setup

## Overview

- Install Python 3.8

- Install Poetry

- Install freetds

  - Can be done with Homebrew; `brew install freetds`

- Install `cython`

  - eg. `pip install cython`

- Clone the PyMedPhys git repo

- Run `poetry install -E all` within the root of the repo

- Run `poetry run pre-commit install`

- Install pandoc

  - Can be done with Homebrew; `brew install pandoc`

You’re good to go.

## Opinionated Recommendations

- Install Python with pyenv

- Install VSCode as your code editor

- Install Jupyter Lab to work with Notebooks